@@ -1,5 +1,4 @@
 #!/bin/sh
-# $Id$
 #
 # This script compares autoconf-based installation against regular builds
 # provided files.
@@ -26,7 +25,7 @@ drop() {
 
 # Removed unused/unshipped stuff
 unused() {
-  grep -E -v '^/(ASNMP|CIAO|TAO_IDL|ace/QoS|apps|contrib|utils)'
+  grep -E -v '^/(ASNMP|TAO_IDL|ace/QoS|apps|contrib|utils)'
 }
 
 F1=`mktemp -t ace_regular.XXXXXXXXXX`
